import 'package:flutter_pom/errors/field_constraint_error.dart';
import 'package:flutter_pom/model/field.dart';

class DoubleField extends Field<double> {
  DoubleField(String name) : super(name);

  @override
  void fromSqlCompatibleValue(dynamic value) {
    if (value == double.infinity || value == double.negativeInfinity) {
      throw UnsupportedError("Infinity values are not supported by SQL Framework");
    }
    if (value == double.nan) {
      throw UnsupportedError("NaN values are not supported for DoubleField.");
    }
    if (value is String) {
      value = double.parse(value);
    } else {
      this.value = value;
    }
  }

  @override
  String get sqlType => "DOUBLE";

  @override
  bool supportsAutoIncrement() {
    return true;
  }

  @override
  String toSqlCompatibleValue() {
    if (value == double.infinity || value == double.negativeInfinity) {
      return '0';
    }
    return value.toString();
  }

  @override
  bool get supportsPrimaryKey => true;

  @override
  double get defaultValue => 0;

}